//@line 37 "/buildbot/linux_repack_31/build/releases/l10n-mozilla-1.9.2/pl/mail/all-l10n.js"

//@line 39 "/buildbot/linux_repack_31/build/releases/l10n-mozilla-1.9.2/pl/mail/all-l10n.js"

pref("general.useragent.locale", "pl");
pref("spellchecker.dictionary", "pl");
